@@ -15,15 +15,13 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
-import os
 import time
-import unittest
 
 from glance.tests import functional
-from glance.tests.utils import execute
 
 from glance import client
 from glance.registry import client as registry_client
+from glance.tests.utils import execute
 
 
 TEST_IMAGE_DATA = '*' * 5 * 1024
@@ -50,7 +48,7 @@ class TestScrubber(functional.FunctionalTest):
         """
 
         self.cleanup()
-        self.start_servers()
+        self.start_servers(**self.__dict__.copy())
 
         client = self._get_client()
         registry = self._get_registry_client()
@@ -128,3 +126,54 @@ class TestScrubber(functional.FunctionalTest):
             self.assertEqual(rec['status'], 'deleted')
 
         self.stop_servers()
+
+    def test_scrubber_app(self):
+        """
+        test that the glance-scrubber script runs successfully when not in
+        daemon mode
+        """
+        self.cleanup()
+        self.start_servers(delayed_delete=True, daemon=False)
+
+        client = self._get_client()
+        registry = self._get_registry_client()
+
+        # add some images and ensure it was successful
+        img_ids = []
+        for i in range(0, 3):
+            meta = client.add_image(TEST_IMAGE_META, TEST_IMAGE_DATA)
+            id = meta['id']
+            img_ids.append(id)
+        filters = {'deleted': True, 'is_public': 'none',
+                   'status': 'pending_delete'}
+        recs = registry.get_images_detailed(filters=filters)
+        self.assertFalse(recs)
+
+        # delete those images
+        for img_id in img_ids:
+            client.delete_image(img_id)
+        recs = registry.get_images_detailed(filters=filters)
+        self.assertTrue(recs)
+
+        filters = {'deleted': True, 'is_public': 'none'}
+        recs = registry.get_images_detailed(filters=filters)
+        self.assertTrue(recs)
+        for rec in recs:
+            self.assertEqual(rec['status'], 'pending_delete')
+
+        # wait for the scrub time on the image to pass
+        time.sleep(self.api_server.scrub_time)
+
+        # scrub images and make sure they get deleted
+        cmd = ("bin/glance-scrubber --config-file %s" %
+               self.scrubber_daemon.conf_file_name)
+        exitcode, out, err = execute(cmd, raise_error=False)
+        self.assertEqual(0, exitcode)
+
+        filters = {'deleted': True, 'is_public': 'none'}
+        recs = registry.get_images_detailed(filters=filters)
+        self.assertTrue(recs)
+        for rec in recs:
+            self.assertEqual(rec['status'], 'deleted')
+
+        self.stop_servers()
